from uuid import uuid4

from database_utils.column_names import ColumnNameFilter, to_safe_snake_case


def test_column_name_map(table):
    column_name_map_from = str(uuid4())
    cnf = ColumnNameFilter(table, column_name_map={column_name_map_from: "column"})
    assert "column" in cnf.filter_row({column_name_map_from: str(uuid4())})


def test_standard_column_name_conversion():
    converted_names = {
        " two   Words  ": "two_words",
        "Multi_Word_Column": "multi_word_column",
        "multiWordColumn": "multi_word_column",
        "MultiWord Column": "multi_word_column",
        "99things": "_99things",
    }
    for k, v in converted_names.items():
        assert to_safe_snake_case(k) == v


def test_columns_no_load(table):
    cnf = ColumnNameFilter(
        table,
        columns_no_load=["column"],
    )
    assert "column" not in cnf.filter_row({"column": str(uuid4())})


def test_drop_non_table_columns(table):
    cnf = ColumnNameFilter(table)
    column2 = str(uuid4())
    assert column2 not in cnf.filter_row({column2: str(uuid4())})
