from uuid import uuid4

import pytest
from database_utils.column_values import ColumnValueFilter


def test_column_value_map(table):
    cvf = ColumnValueFilter(table, column_value_map={"map_from": "map_to"})
    filtered_row = cvf.filter_row({"column": "map_from"})
    assert filtered_row["column"] == "map_to"


def test_column_value_converter(table):
    cvf = ColumnValueFilter(table, column_value_converter=lambda v: v + v)
    filtered_row = cvf.filter_row({"column": "value"})
    assert filtered_row["column"] == "valuevalue"


def test_column_value_converter_map(table):
    cvf = ColumnValueFilter(
        table, column_value_converter_map={"column": lambda v: v + v}
    )
    filtered_row = cvf.filter_row({"column": "value"})
    assert filtered_row["column"] == "valuevalue"


def test_values_no_load(table):
    cvf = ColumnValueFilter(table, values_no_load=["null"])
    assert "column" not in cvf.filter_row({"column": "null"})


def test_drop_on_type_conversion_fail(table):
    def conveter(value):
        raise RuntimeError

    cvf = ColumnValueFilter(
        table,
        column_value_converter=conveter,
        drop_on_type_conversion_fail=True,
    )
    row = {"column": str(uuid4())}
    filtered_row = cvf.filter_row(row)

    assert "column" not in filtered_row

    cvf = ColumnValueFilter(
        table,
        column_value_converter=conveter,
        drop_on_type_conversion_fail=False,
    )
    with pytest.raises(RuntimeError):
        cvf.filter_row({"column": str(uuid4())})
